pub struct Program<APP, MSG, B> { /* private fields */ }Expand description
Holds the app and the dom updater This is passed into the event listener and the dispatch program will be called after the event is triggered.
Implementations